@@ -37,7 +37,7 @@ struct Regenerator {
     top_level_vars: Vec<VarDeclarator>,
 }
 
-fn rt(global_mark: Mark, rt: Ident) -> Stmt {
+fn require_rt(global_mark: Mark, rt: Ident) -> Stmt {
     Stmt::Decl(Decl::Var(VarDecl {
         span: DUMMY_SP,
         kind: VarDeclKind::Var,
@@ -140,38 +140,55 @@ impl Fold for Regenerator {
 
         let f = f.fold_children_with(self);
 
-        let marked = private_ident!("_marked");
+        if f.function.is_generator {
+            let marked = private_ident!("_marked");
 
-        self.top_level_vars.push(VarDeclarator {
-            span: DUMMY_SP,
-            name: Pat::Ident(marked.clone().into()),
-            init: Some(Box::new(Expr::Call(CallExpr {
+            self.top_level_vars.push(VarDeclarator {
                 span: DUMMY_SP,
-                callee: self
-                    .regenerator_runtime
-                    .clone()
-                    .unwrap()
-                    .make_member(quote_ident!("mark"))
-                    .as_callee(),
-                args: vec![f.ident.clone().as_arg()],
-                type_args: None,
-            }))),
-            definite: false,
-        });
+                name: Pat::Ident(marked.clone().into()),
+                init: Some(Box::new(Expr::Call(CallExpr {
+                    span: DUMMY_SP,
+                    callee: self
+                        .regenerator_runtime
+                        .clone()
+                        .unwrap()
+                        .make_member(quote_ident!("mark"))
+                        .as_callee(),
+                    args: vec![f.ident.clone().as_arg()],
+                    type_args: None,
+                }))),
+                definite: false,
+            });
 
-        let (i, function) = self.fold_fn(Some(f.ident), marked, f.function);
+            let (i, function) = self.fold_fn(Some(f.ident), marked, f.function);
 
-        FnDecl {
-            ident: i.unwrap(),
-            function,
-            ..f
+            FnDecl {
+                ident: i.unwrap(),
+                function,
+                ..f
+            }
+        } else {
+            f
         }
     }
 
     fn fold_module(&mut self, m: Module) -> Module {
         let mut m: Module = m.fold_children_with(self);
         if let Some(rt_ident) = self.regenerator_runtime.take() {
-            prepend(&mut m.body, rt(self.global_mark, rt_ident).into());
+            let specifier = ImportSpecifier::Default(ImportDefaultSpecifier {
+                span: DUMMY_SP,
+                local: rt_ident,
+            });
+            prepend(
+                &mut m.body,
+                ModuleItem::ModuleDecl(ModuleDecl::Import(ImportDecl {
+                    span: DUMMY_SP,
+                    specifiers: vec![specifier],
+                    src: quote_str!("regenerator-runtime"),
+                    type_only: Default::default(),
+                    asserts: Default::default(),
+                })),
+            );
         }
         m
     }
@@ -269,7 +286,7 @@ impl Fold for Regenerator {
     fn fold_script(&mut self, s: Script) -> Script {
         let mut s: Script = s.fold_children_with(self);
         if let Some(rt_ident) = self.regenerator_runtime.take() {
-            prepend(&mut s.body, rt(self.global_mark, rt_ident).into());
+            prepend(&mut s.body, require_rt(self.global_mark, rt_ident).into());
         }
         s
     }
